@@ -62,7 +62,20 @@ badword_regexes = [
     r"छिनार",
     r"मुट्ठ",
     r"पागल",
-    r"हरामखोर"
+    r"हरामखोर",
+    r"बहनचोद",
+    r"गांडू",
+    r"सूअर",
+    r"हरामी",
+    r"हराम जादा",
+    r"लंड",
+    r"कुतिया",
+    r"कमीना",
+    r"कमीनी",
+    r"गधा",
+    r"हिजड़ा",
+    r"हिज्र",
+    r"साली",
 ]
 
 badwords = RegexMatches(name + ".badwords", badword_regexes,
@@ -130,7 +143,20 @@ informal_regexes = [
     r"हुदंग",
     r"हुल्लड़",
     r"कुत्ते",
-    r"कुत्ता"
+    r"कुत्ता",
+    r"अच्छा",
+    r"वाह",
+    r"वाह वाह",
+    r"शाबाश",
+    r"हैं",
+    r"सुनो",
+    r"सुनो ना",
+    r"और फिर",
+    r"हां बोलो",
+    r"सच में",
+    r"फुद्दू",
+    r"मूत",
+    r"चुप कर",
 ]
 
 informals = RegexMatches(name + ".informals", informal_regexes,
