@@ -2,15 +2,20 @@ import pickle
 from unittest.mock import patch
 
 import pytest
-
 from revscoring.datasources import revision_oriented as ro
 from revscoring.datasources.meta import vectorizers
 from revscoring.dependencies import solve
 from revscoring.features import wikitext
 
-test_vectors = {'a': [1] * 300,
-                'b': [1] * 300,
-                'c': [1] * 300}
+
+class FakeVectors(dict):
+    pass
+
+test_vectors = FakeVectors({
+                'a': [1] * 100,
+                'b': [2] * 100,
+                'c': [3] * 100})
+test_vectors.vector_size = 100
 
 
 def vectorize_words(words):
@@ -21,11 +26,11 @@ def test_word2vec():
     wv = vectorizers.word2vec(wikitext.revision.datasources.words,
                               vectorize_words, name='word vectors')
     vector = solve(wv, cache={ro.revision.text: 'a bv c d'})
-    assert len(vector) == 4
-    assert len(vector[0]) == 300
+    assert len(vector) == 2
+    assert len(vector[0]) == 100
     vector = solve(wv, cache={ro.revision.text: ''})
     assert len(vector) == 1
-    assert len(vector[0]) == 300
+    assert len(vector[0]) == 100
 
     assert pickle.loads(pickle.dumps(wv)) == wv
 
@@ -34,7 +39,7 @@ def test_word2vec():
 def test_loadkv_path(kv):
     kv.KeyedVectors.load_word2vec_format.return_value = test_vectors
     vectorizers.KeyedVectors = kv.KeyedVectors
-    vectors = vectorizers.word2vec.load_kv(path='foo')
+    vectors = vectorizers.word2vec.load_word2vec(path='foo')
     assert vectors is not None
 
 
@@ -43,4 +48,4 @@ def test_loadkv_filename_none(kv):
     kv.KeyedVectors.load_word2vec_format.side_effect = FileNotFoundError
     vectorizers.KeyedVectors = kv.KeyedVectors
     assert pytest.raises(FileNotFoundError,
-                         vectorizers.word2vec.load_kv, filename='foo')
+                         vectorizers.word2vec.load_word2vec, filename='foo')
